@@ -1,10 +1,18 @@
 import os
 from xbmcswift2.logger import log
+from xbmcswift2.mockxbmc import utils
 
 
 class Addon(object):
-    def __init__(self, id):
-        self._id = id
+
+    def __init__(self, id=None):
+        # In CLI mode, xbmcswift2 must be run from the root of the addon
+        # directory, so we can rely on getcwd() being correct.
+        addonxml = os.path.join(os.getcwd(), 'addon.xml')
+        self._info = {
+            'id': id or utils.get_addon_id(addonxml),
+            'name': utils.get_addon_name(addonxml),
+        }
         self._strings = {}
         self._settings = {}
 
@@ -13,7 +21,7 @@ class Addon(object):
             'fanart', 'icon', 'id', 'name', 'path', 'profile', 'stars', 'summary',
             'type', 'version']
         assert id in properties, '%s is not a valid property.' % id
-        return True
+        return self._info.get(id, 'Unavailable')
 
     def getLocalizedString(self, id):
         key = str(id)
